command

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 13, 2024 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package command provides the root command for the mindnum.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRootCommand

func NewRootCommand(
	cobra proxy.Cobra,
	version string,
	format *string,
	output *string,
) proxy.Command

Types

type Cli

type Cli struct {
	Cobra       proxy.Cobra
	Version     string
	RootCommand proxy.Command
}

func NewCli

func NewCli(
	cobra proxy.Cobra,
	version string,
) *Cli

func (*Cli) Run

func (c *Cli) Run() int

Directories

Path Synopsis
Package mindnum provides the sub commands for the mindnum.
Package mindnum provides the sub commands for the mindnum.

Jump to