errors

package
v1.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package error provides error handling for the mindnum.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(msg string) error

New returns a new error with the given message

func Wrap

func Wrap(err error, msg string) error

Wrap returns a new error that wraps the given error with the given message

Types

This section is empty.

Jump to