utility

package
v1.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package utility is a generated GoMock package.

Package utility provides utility functions for the mindnum.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCapturer

func NewCapturer(
	os proxy.Os,
	stdBuffer proxy.Buffer,
	errBuffer proxy.Buffer,
) *capturer

NewCapturer returns a new instance of the capturer struct.

Types

type Capturer

type Capturer interface {
	CaptureOutput(fnc func()) (string, string, error)
}

Capturer is an interface that captures the output of a function.

type MockCapturer added in v1.1.4

type MockCapturer struct {
	// contains filtered or unexported fields
}

MockCapturer is a mock of Capturer interface.

func NewMockCapturer added in v1.1.4

func NewMockCapturer(ctrl *gomock.Controller) *MockCapturer

NewMockCapturer creates a new mock instance.

func (*MockCapturer) CaptureOutput added in v1.1.4

func (m *MockCapturer) CaptureOutput(fnc func()) (string, string, error)

CaptureOutput mocks base method.

func (*MockCapturer) EXPECT added in v1.1.4

EXPECT returns an object that allows the caller to indicate expected use.

type MockCapturerMockRecorder added in v1.1.4

type MockCapturerMockRecorder struct {
	// contains filtered or unexported fields
}

MockCapturerMockRecorder is the mock recorder for MockCapturer.

func (*MockCapturerMockRecorder) CaptureOutput added in v1.1.4

func (mr *MockCapturerMockRecorder) CaptureOutput(fnc any) *gomock.Call

CaptureOutput indicates an expected call of CaptureOutput.

type VersionUtil

type VersionUtil interface {
	GetVersion(version string) string
}

VersionUtil is an interface that provides the version of the application.

func NewVersionUtil

func NewVersionUtil(
	debug proxy.Debug,
) VersionUtil

NewVersionUtil returns a new instance of the versionUtil struct.

Jump to