utility

package
v1.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package utility provides utility functions for the mindnum.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCapturer

func NewCapturer(
	stdBuffer proxy.Buffer,
	errBuffer proxy.Buffer,
) *capturer

NewCapturer returns a new instance of the capturer struct.

Types

type Capturable

type Capturable interface {
	CaptureOutput(fnc func()) (string, string, error)
}

Capturable is an interface that captures the output of a function.

type VersionUtil

type VersionUtil interface {
	GetVersion(version string) string
}

VersionUtil is an interface that provides the version of the application.

func NewVersionUtil

func NewVersionUtil(
	debug proxy.Debug,
) VersionUtil

NewVersionUtil returns a new instance of the versionUtil struct.

Jump to