Documentation
¶
Overview ¶
Package utility provides utility functions for the mindnum.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Capturable ¶
Capturable is an interface that captures the output of a function.
type VersionUtil ¶
VersionUtil is an interface that provides the version of the application.
func NewVersionUtil ¶
func NewVersionUtil( debug proxy.Debug, ) VersionUtil
NewVersionUtil returns a new instance of the versionUtil struct.
Click to show internal directories.
Click to hide internal directories.